@@ -1,49 +1,49 @@
 use criterion::{criterion_group, criterion_main, BatchSize, Criterion};
 use metrics::{Key, Label};
-use metrics_util::{MetricKind, Registry};
+use metrics_util::{Registry, StandardPrimitives};
 
 fn registry_benchmark(c: &mut Criterion) {
     let mut group = c.benchmark_group("registry");
     group.bench_function("cached op (basic)", |b| {
-        let registry: Registry<Key, ()> = Registry::new();
+        let registry = Registry::<StandardPrimitives>::new();
         static KEY_NAME: &'static str = "simple_key";
         static KEY_DATA: Key = Key::from_static_name(&KEY_NAME);
 
-        b.iter(|| registry.op(MetricKind::Counter, &KEY_DATA, |_| (), || ()))
+        b.iter(|| registry.get_or_create_counter(&KEY_DATA, |_| ()))
     });
     group.bench_function("cached op (labels)", |b| {
-        let registry: Registry<Key, ()> = Registry::new();
+        let registry = Registry::<StandardPrimitives>::new();
         static KEY_NAME: &'static str = "simple_key";
         static KEY_LABELS: [Label; 1] = [Label::from_static_parts("type", "http")];
         static KEY_DATA: Key = Key::from_static_parts(&KEY_NAME, &KEY_LABELS);
 
-        b.iter(|| registry.op(MetricKind::Counter, &KEY_DATA, |_| (), || ()))
+        b.iter(|| registry.get_or_create_counter(&KEY_DATA, |_| ()))
     });
     group.bench_function("uncached op (basic)", |b| {
         b.iter_batched_ref(
-            || Registry::<Key, ()>::new(),
+            || Registry::<StandardPrimitives>::new(),
             |registry| {
                 let key = "simple_key".into();
-                registry.op(MetricKind::Counter, &key, |_| (), || ())
+                registry.get_or_create_counter(&key, |_| ())
             },
             BatchSize::SmallInput,
         )
     });
     group.bench_function("uncached op (labels)", |b| {
         b.iter_batched_ref(
-            || Registry::<Key, ()>::new(),
+            || Registry::<StandardPrimitives>::new(),
             |registry| {
                 let labels = vec![Label::new("type", "http")];
                 let key = ("simple_key", labels).into();
-                registry.op(MetricKind::Counter, &key, |_| (), || ())
+                registry.get_or_create_counter(&key, |_| ())
             },
             BatchSize::SmallInput,
         )
     });
-    group.bench_function("registry overhead", |b| {
+    group.bench_function("creation overhead", |b| {
         b.iter_batched(
             || (),
-            |_| Registry::<Key, ()>::new(),
+            |_| Registry::<StandardPrimitives>::new(),
             BatchSize::NumIterations(1),
         )
     });
@@ -60,9 +60,7 @@ fn registry_benchmark(c: &mut Criterion) {
             Key::from_static_parts(&KEY_NAME, &LABELS)
         })
     });
-    group.bench_function("owned key overhead (basic)", |b| {
-        b.iter(|| Key::from_name("simple_key"))
-    });
+    group.bench_function("owned key overhead (basic)", |b| b.iter(|| Key::from_name("simple_key")));
     group.bench_function("owned key overhead (labels)", |b| {
         b.iter(|| {
             let key = "simple_key";
